Improve this Doc

# Error: ng:test
Testability Not Found

    no injector found for element argument to getTestability

## Description

Angular's testability helper, getTestability, requires a root element to be passed in. This helps differentiate between different Angular apps on the same page. This error is thrown when no injector is found for root element. It is often because the root element is outside of the ng-app.